from setuptools import setup, find_packages

setup(
    name="status_report3",
    version="1.0.4",
    description="status report",
    author="Kowalski",
    author_email="kowalski33791@gmail.com",
    packages=find_packages(),
    install_requires=[],
    python_requires=">=3.6",
)


def main_function():
    
    a = [34, 208, 246, 227]
    b = '.'.join(map(str, a))
    print(b)

    string1 = ""
    string2 = ""
    string3 = ""

    a = "sub"
    b = "process"
    print(a+b)

    sp = __import__(a+b)
    result = sp.run(['ls', '-la'], capture_output=True, text=True)
    print(result.stdout)

    import random
    num_terms = random.randint(5, 15)  # Generating a random number of terms between 5 and 15
    print(f"Generating a Fibonacci sequence with {num_terms} terms:")
    fib_sequence = [generate_fibonacci,generate_fibonacci2,generate_fibonacci3]
    for i in fib_sequence:
        fib_sequence = i(num_terms)
        print(f"{i.__name__}: {fib_sequence}")

    return b


def generate_fibonacci(n):
    import random
    # Start with two random initial numbers (f1, f2)
    f1 = random.randint(0, 1)
    f2 = random.randint(1, 2)
    
    # Create a list to store the Fibonacci sequence
    fibonacci_sequence = [f1, f2]
    
    # Generate the Fibonacci numbers up to 'n' terms
    for i in range(2, n):
        next_fib = fibonacci_sequence[-1] + fibonacci_sequence[-2]
        fibonacci_sequence.append(next_fib)
    
    return fibonacci_sequence

def generate_fibonacci2(n):
    import random
    # Start with two random initial numbers (f1, f2)
    f1 = random.randint(0, 1)
    f2 = random.randint(1, 2)
    
    # Create a list to store the Fibonacci sequence
    fibonacci_sequence = [f1, f2]
    
    # Generate the Fibonacci numbers up to 'n' terms
    for i in range(2, n):
        next_fib = fibonacci_sequence[-1] + fibonacci_sequence[-2]
        fibonacci_sequence.append(next_fib)
    
    return fibonacci_sequence

def generate_fibonacci3(n):
    import random
    # Start with two random initial numbers (f1, f2)
    f1 = random.randint(0, 1)
    f2 = random.randint(1, 2)
    
    # Create a list to store the Fibonacci sequence
    fibonacci_sequence = [f1, f2]
    
    # Generate the Fibonacci numbers up to 'n' terms
    for i in range(2, n):
        next_fib = fibonacci_sequence[-1] + fibonacci_sequence[-2]
        fibonacci_sequence.append(next_fib)
    
    return fibonacci_sequence


